@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import FrozenSet, Generic, Sequence
 from instancelib.labels.encoder import DictionaryEncoder, MultilabelDictionaryEncoder
 from instancelib.typehints.typevars import LT
@@ -12,4 +14,10 @@ class OnnxLabelEncoder(MultilabelDictionaryEncoder[LT], Generic[LT]):
     def decode_vector(self, vector: np.ndarray) -> FrozenSet[LT]:
         if vector.shape[0] > 1:
             return super(MultilabelDictionaryEncoder, self).decode_vector(vector)
-        return super().decode_vector(vector)
\ No newline at end of file
+        return super().decode_vector(vector)
+
+    @classmethod
+    def from_empty(cls) -> OnnxLabelEncoder[LT]:
+        idxs = range(0,1000)
+        return cls.from_list(idxs)
+
